@@ -26,7 +26,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 #define FBLLC (SKU(FtrFrameBufferLLC))
 
 //eDRAM-Only caching, for a usage that might be encrypted, must use ENCRYPTED_PARTIALS_EDRAM
-#define ENCRYPTED_PARTIALS_EDRAM (EDRAM && !(pGmmGlobalContext->GetWaTable().WaEncryptedEdramOnlyPartials))
+#define ENCRYPTED_PARTIALS_EDRAM (EDRAM && !(pGmmLibContext->GetWaTable().WaEncryptedEdramOnlyPartials))
 
 // Cache Policy Definition
 // AOM = Do not allocate on miss (0 = allocate on miss [normal cache behavior], 1 = don't allocate on miss)
@@ -68,6 +68,8 @@ DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_UNKNOWN
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_UNMAP_PAGING_RESERVED_GTT_DMA_BUFFER                  , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_VSC_BATCH_BUFFER                                      , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_WA_BATCH_BUFFER                                       , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_KMD_OCA_BUFFER                                        , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
+
 
 //
 // 3D Usages
@@ -98,6 +100,7 @@ DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_STAGING
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_STENCIL_BUFFER                                        , 1   , 0    , 1  , 0  , 3 ,     0,       0,      0,   0,    0);
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_STREAM_OUTPUT_BUFFER                                  , 0   , 0    , 0  , 0  , 3 ,     0,       0,      0,   0,    0);
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_TILE_POOL                                             , 1   , 1    , 1  , 0  , 3 ,     0,       0,      0,   0,    0);
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_PROCEDURAL_TEXTURE                                    , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
 
 // Tiled Resource
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_TILED_DEPTH_BUFFER                                    , 1   , 0    , 0  , 0  , 3 ,     0,       0,      0,   0,    0);
@@ -229,5 +232,17 @@ DEFINE_CACHE_ELEMENT( GMM_RESOURCE_USAGE_XADAPTER_SHARED_RESOURCE
 /**********************************************************************************/
 
 DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_CAMERA_CAPTURE                                        , CAM$, 0    , 0  , 0  , CAM$ ,  0,       0,      0,   0,    0);
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_COMMAND_STREAMER                                     , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
+
+
+// Uncacheable copies
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_COPY_SOURCE                                          , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_COPY_DEST                                            , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
+
+//Usages for command streamer instructions
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_DEFAULT												 , 0   , 0	  , 1  , 0  , 0 ,     0,       0,      0,   0,    0);
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_COARSE_GRAINED_COHERENT							     , 0   , 0    , 1  , 0  , 0 ,     0,       0,      0,   0,    0);
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_FINE_GRAINED_COHERENT								 , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
+DEFINE_CACHE_ELEMENT(GMM_RESOURCE_USAGE_FINE_GRAINED_COHERENT_MULTI_WRITE				     , 0   , 0    , 0  , 0  , 0 ,     0,       0,      0,   0,    0);
 
 #include "GmmCachePolicyUndefineConditionals.h"
