@@ -29,11 +29,10 @@ OTHER DEALINGS IN THE SOFTWARE.
 ///
 /// @param[in]  Platform: Contains information about platform to initialize an object
 /////////////////////////////////////////////////////////////////////////////////////
-GmmLib::PlatformInfoGen8::PlatformInfoGen8(PLATFORM &Platform)
-    : PlatformInfo(Platform)
+GmmLib::PlatformInfoGen8::PlatformInfoGen8(PLATFORM &Platform, Context *pGmmLibContext)
+    : PlatformInfo(Platform, pGmmLibContext)
 {
-    __GMM_ASSERTPTR(pGmmGlobalContext, VOIDRETURN);
-
+    __GMM_ASSERTPTR(pGmmLibContext, VOIDRETURN);
     // --------------------------
     // Non Native Dispay Interface buffer restriction. Register Ref: DSPACNTR, DSPASTRIDE, DSPASURF
     // Clamping res based on 2 Nndi buffers and GMM_NNDI_SEGMENT_SIZE reserved gfx memory
@@ -230,7 +229,7 @@ GmmLib::PlatformInfoGen8::PlatformInfoGen8(PLATFORM &Platform)
     Data.Texture2DSurface.LockPitchAlignment   = GMM_BYTES(32);
     Data.Texture2DSurface.RenderPitchAlignment = GMM_BYTES(32);
     Data.Texture2DSurface.MinPitch             = GMM_BYTES(32);
-    Data.Texture2DSurface.MaxPitch             = (pGmmGlobalContext->GetWaTable().WaRestrictPitch128KB) ? GMM_KBYTE(128) : GMM_KBYTE(256);
+    Data.Texture2DSurface.MaxPitch             = (pGmmLibContext->GetWaTable().WaRestrictPitch128KB) ? GMM_KBYTE(128) : GMM_KBYTE(256);
     Data.Texture2DSurface.MinAllocationSize    = PAGE_SIZE;
     Data.Texture2DSurface.MinHeight            = GMM_SCANLINES(1);
     Data.Texture2DSurface.MinWidth             = GMM_PIXELS(1);
@@ -290,7 +289,7 @@ GmmLib::PlatformInfoGen8::PlatformInfoGen8(PLATFORM &Platform)
     Data.CubeSurface.LockPitchAlignment   = GMM_BYTES(32);
     Data.CubeSurface.RenderPitchAlignment = GMM_BYTES(32);
     Data.CubeSurface.MinPitch             = GMM_BYTES(32);
-    Data.CubeSurface.MaxPitch             = (pGmmGlobalContext->GetWaTable().WaRestrictPitch128KB) ? GMM_KBYTE(128) : GMM_KBYTE(256);
+    Data.CubeSurface.MaxPitch             = (pGmmLibContext->GetWaTable().WaRestrictPitch128KB) ? GMM_KBYTE(128) : GMM_KBYTE(256);
     Data.CubeSurface.MinAllocationSize    = PAGE_SIZE;
     Data.CubeSurface.MinHeight            = GMM_SCANLINES(1);
     Data.CubeSurface.MinWidth             = GMM_PIXELS(1);
@@ -309,7 +308,7 @@ GmmLib::PlatformInfoGen8::PlatformInfoGen8(PLATFORM &Platform)
     Data.Texture3DSurface.LockPitchAlignment   = GMM_BYTES(32);
     Data.Texture3DSurface.RenderPitchAlignment = GMM_BYTES(32);
     Data.Texture3DSurface.MinPitch             = GMM_BYTES(32);
-    Data.Texture3DSurface.MaxPitch             = (pGmmGlobalContext->GetWaTable().WaRestrictPitch128KB) ? GMM_KBYTE(128) : GMM_KBYTE(256);
+    Data.Texture3DSurface.MaxPitch             = (pGmmLibContext->GetWaTable().WaRestrictPitch128KB) ? GMM_KBYTE(128) : GMM_KBYTE(256);
     Data.Texture3DSurface.MinAllocationSize    = PAGE_SIZE;
     Data.Texture3DSurface.MinHeight            = GMM_SCANLINES(1);
     Data.Texture3DSurface.MinWidth             = GMM_PIXELS(1);
@@ -341,7 +340,7 @@ GmmLib::PlatformInfoGen8::PlatformInfoGen8(PLATFORM &Platform)
     // --------------------------
     // Cursor surface restricion. Register Ref: CURACNTR, CURABASE
     // --------------------------
-    Data.Cursor.Alignment            = pGmmGlobalContext->GetWaTable().WaCursor16K ? GMM_KBYTE(16) : PAGE_SIZE;
+    Data.Cursor.Alignment            = pGmmLibContext->GetWaTable().WaCursor16K ? GMM_KBYTE(16) : PAGE_SIZE;
     Data.Cursor.PitchAlignment       = 1;
     Data.Cursor.LockPitchAlignment   = 1;
     Data.Cursor.RenderPitchAlignment = 1;
@@ -365,7 +364,7 @@ GmmLib::PlatformInfoGen8::PlatformInfoGen8(PLATFORM &Platform)
     //--------------------------
     // Fence paramaters. Register Ref: FENCE
     //--------------------------
-    Data.NumberFenceRegisters = pGmmGlobalContext->GetWaTable().Wa16TileFencesOnly ? 16 : 32;
+    Data.NumberFenceRegisters = pGmmLibContext->GetWaTable().Wa16TileFencesOnly ? 16 : 32;
     Data.FenceLowBoundShift   = 12;
     Data.FenceLowBoundMask    = GFX_MASK(12, 31);
     Data.MinFenceSize         = GMM_MBYTE(1);
@@ -414,7 +413,7 @@ GmmLib::PlatformInfoGen8::PlatformInfoGen8(PLATFORM &Platform)
     Data.XAdapter.RenderPitchAlignment = GMM_BYTES(D3DKMT_CROSS_ADAPTER_RESOURCE_PITCH_ALIGNMENT);
     Data.XAdapter.LockPitchAlignment   = GMM_BYTES(D3DKMT_CROSS_ADAPTER_RESOURCE_PITCH_ALIGNMENT);
     Data.XAdapter.MinPitch             = GMM_BYTES(32);
-    Data.XAdapter.MaxPitch             = (pGmmGlobalContext->GetWaTable().WaRestrictPitch128KB) ? GMM_KBYTE(128) : GMM_KBYTE(256);
+    Data.XAdapter.MaxPitch             = (pGmmLibContext->GetWaTable().WaRestrictPitch128KB) ? GMM_KBYTE(128) : GMM_KBYTE(256);
     Data.XAdapter.MinAllocationSize    = PAGE_SIZE;
     Data.XAdapter.MinHeight            = GMM_SCANLINES(1);
     Data.XAdapter.MinWidth             = GMM_PIXELS(1);
