@@ -61,6 +61,7 @@ typedef enum GMM_FLATCCS_FORMAT_ENUM
     GMM_FLATCCS_FORMAT_R32F1,
     GMM_FLATCCS_FORMAT_R32S1 = GMM_FLATCCS_FORMAT_R32F1,
     GMM_FLATCCS_FORMAT_R32U1 = GMM_FLATCCS_FORMAT_R32F1,
+    GMM_FLATCCS_FORMAT_D32U  = GMM_FLATCCS_FORMAT_R32F1,
 
     GMM_FLATCCS_FORMAT_R16F1,
     GMM_FLATCCS_FORMAT_R16S1 = GMM_FLATCCS_FORMAT_R16F1,
@@ -79,7 +80,11 @@ typedef enum GMM_FLATCCS_FORMAT_ENUM
     GMM_FLATCCS_FORMAT_Y216,
     GMM_FLATCCS_FORMAT_Y416,
     GMM_FLATCCS_FORMAT_P010,
+    GMM_FLATCCS_FORMAT_P010_L = GMM_FLATCCS_FORMAT_P010,         //MC 7h
+    GMM_FLATCCS_FORMAT_P010_C = GMM_FLATCCS_FORMAT_P010,         //MC 7h
     GMM_FLATCCS_FORMAT_P016,
+    GMM_FLATCCS_FORMAT_P016_L = GMM_FLATCCS_FORMAT_P016,         //MC 8h
+    GMM_FLATCCS_FORMAT_P016_C = GMM_FLATCCS_FORMAT_P016,         //MC 8h
     GMM_FLATCCS_FORMAT_AYUV,
     GMM_FLATCCS_FORMAT_ARGB8b,
     GMM_FLATCCS_FORMAT_SWAPY,
@@ -87,6 +92,8 @@ typedef enum GMM_FLATCCS_FORMAT_ENUM
     GMM_FLATCCS_FORMAT_SWAPUVY,
     GMM_FLATCCS_FORMAT_RGB10b,
     GMM_FLATCCS_FORMAT_NV12,
+    GMM_FLATCCS_FORMAT_NV12_L = GMM_FLATCCS_FORMAT_NV12,
+    GMM_FLATCCS_FORMAT_NV12_C = GMM_FLATCCS_FORMAT_NV12,
 
     GMM_FLATCCS_FORMAT_YCRCB_SWAPUV = GMM_FLATCCS_FORMAT_SWAPUV,
     GMM_FLATCCS_FORMAT_YCRCB_SWAPUVY = GMM_FLATCCS_FORMAT_SWAPUVY,
@@ -97,6 +104,99 @@ typedef enum GMM_FLATCCS_FORMAT_ENUM
     GMM_FLATCCS_FORMAT_INVALID,                          //equal to last valid encoding plus one
 } GMM_FLATCCS_FORMAT;
 
+typedef enum GMM_XE2_UNIFIED_COMP_FORMAT_ENUM
+{
+    GMM_XE2_UNIFIED_COMP_FORMAT_R8     = 0, //0h  bpc8 R
+    GMM_XE2_UNIFIED_COMP_MIN_FORMAT    = GMM_XE2_UNIFIED_COMP_FORMAT_R8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_NV12_L = GMM_XE2_UNIFIED_COMP_FORMAT_R8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_D32U   = GMM_XE2_UNIFIED_COMP_FORMAT_R8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R8U    = GMM_XE2_UNIFIED_COMP_FORMAT_R8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R8S    = GMM_XE2_UNIFIED_COMP_FORMAT_R8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R8U1   = GMM_XE2_UNIFIED_COMP_FORMAT_R8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R8S1   = GMM_XE2_UNIFIED_COMP_FORMAT_R8,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG8, //1h  bpc8 RG
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGB5A1 = GMM_XE2_UNIFIED_COMP_FORMAT_RG8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA4  = GMM_XE2_UNIFIED_COMP_FORMAT_RG8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_B5G6R5 = GMM_XE2_UNIFIED_COMP_FORMAT_RG8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_NV12_C = GMM_XE2_UNIFIED_COMP_FORMAT_RG8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG8U   = GMM_XE2_UNIFIED_COMP_FORMAT_RG8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG8S   = GMM_XE2_UNIFIED_COMP_FORMAT_RG8,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA8, // 2h  bpc8 RGBA
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA8U        = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA8S        = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_YUY2          = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_AYUV          = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB         = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_SWAPY         = GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB,
+    GMM_XE2_UNIFIED_COMP_FORMAT_SWAPUV        = GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB,
+    GMM_XE2_UNIFIED_COMP_FORMAT_SWAPUVY       = GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB,
+    GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB_SWAPUV  = GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB,
+    GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB_SWAPUVY = GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB,
+    GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB_SWAPY   = GMM_XE2_UNIFIED_COMP_FORMAT_YCRCB,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGB10A2, // 3h  3bpc10_1bpc2 RGBA10A2
+    GMM_XE2_UNIFIED_COMP_FORMAT_Y410 = GMM_XE2_UNIFIED_COMP_FORMAT_RGB10A2,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG11B10, // 4h - 2bpc11_1bpc10 RG11B10
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_R16, // 5h - bpc16 R
+    GMM_XE2_UNIFIED_COMP_FORMAT_R16U   = GMM_XE2_UNIFIED_COMP_FORMAT_R16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R16S   = GMM_XE2_UNIFIED_COMP_FORMAT_R16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R16F1  = GMM_XE2_UNIFIED_COMP_FORMAT_R16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R16U1  = GMM_XE2_UNIFIED_COMP_FORMAT_R16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R16S1  = GMM_XE2_UNIFIED_COMP_FORMAT_R16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_P010_L = GMM_XE2_UNIFIED_COMP_FORMAT_R16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_P016_L = GMM_XE2_UNIFIED_COMP_FORMAT_R16,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG16, // 6h  bpc16 RG
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG16U  = GMM_XE2_UNIFIED_COMP_FORMAT_RG16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG16F  = GMM_XE2_UNIFIED_COMP_FORMAT_RG16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG16S  = GMM_XE2_UNIFIED_COMP_FORMAT_RG16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_P010_C = GMM_XE2_UNIFIED_COMP_FORMAT_RG16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_P016_C = GMM_XE2_UNIFIED_COMP_FORMAT_RG16,
+
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA16, // 7h - bpc16 RGBA
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA16U = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA16F = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA16,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA16S = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA16,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_R32, // 8h - bpc32 R
+    GMM_XE2_UNIFIED_COMP_FORMAT_R32U  = GMM_XE2_UNIFIED_COMP_FORMAT_R32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R32F  = GMM_XE2_UNIFIED_COMP_FORMAT_R32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R32S  = GMM_XE2_UNIFIED_COMP_FORMAT_R32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R32U1 = GMM_XE2_UNIFIED_COMP_FORMAT_R32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R32F1 = GMM_XE2_UNIFIED_COMP_FORMAT_R32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_R32S1 = GMM_XE2_UNIFIED_COMP_FORMAT_R32,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG32, // 9h - bpc32 RG
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG32U = GMM_XE2_UNIFIED_COMP_FORMAT_RG32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG32F = GMM_XE2_UNIFIED_COMP_FORMAT_RG32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RG32S = GMM_XE2_UNIFIED_COMP_FORMAT_RG32,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA32, // 10h - bpc32 RGBA
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA32U = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA32F = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA32,
+    GMM_XE2_UNIFIED_COMP_FORMAT_RGBA32S = GMM_XE2_UNIFIED_COMP_FORMAT_RGBA32,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_Y210, // 11h  packed YUV (Y210, Y416, Y216)
+    GMM_XE2_UNIFIED_COMP_FORMAT_Y216 = GMM_XE2_UNIFIED_COMP_FORMAT_Y210,
+    GMM_XE2_UNIFIED_COMP_FORMAT_Y416 = GMM_XE2_UNIFIED_COMP_FORMAT_Y210,
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RSVD1, // 12h  Unused
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_HW_RSVD, // 13h  HW Stateless from MMIO or Uncompressed
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_RSVD2_, // 13h  Stateless MMIO CMF?
+
+    GMM_XE2_UNIFIED_COMP_FORMAT_ML8 = 0xF, // 15h  ML and Lossy-Compressed textures
+    GMM_XE2_UNIFIED_COMP_MAX_FORMAT = GMM_XE2_UNIFIED_COMP_FORMAT_ML8,
+    GMM_XE2_UNIFIED_COMP_FORMAT_INVALID, //equal to last valid encoding plus one
+} GMM_XE2_UNIFIED_COMP_FORMAT;
+
+
 typedef enum GMM_UNIFIED_COMP_FORMAT_ENUM
 {
     GMM_UNIFIED_COMP_FORMAT_RGBA32F = 0, //0h - bpc32 RGBA F/S
@@ -286,14 +386,16 @@ typedef enum GMM_TILE_MODE_ENUM
     DEFINE_TILE_BPEs( YS_2D_16X ),
     DEFINE_TILE_BPEs( YS_3D     ),
 
-    // XE-HP
+    // XE_HP/Xe2_LPG
     TILE4,
     DEFINE_TILE_BPEs( _64_1D ),
     DEFINE_TILE_BPEs( _64_2D ),
     DEFINE_TILE_BPEs( _64_2D_2X),
     DEFINE_TILE_BPEs( _64_2D_4X),
     DEFINE_TILE_BPEs( _64_3D),
-
+    // Xe2 above
+    DEFINE_TILE_BPEs(_64_2D_8X),
+    DEFINE_TILE_BPEs(_64_2D_16X),
     GMM_TILE_MODES
 }GMM_TILE_MODE;
 
