@@ -178,6 +178,12 @@ namespace GmmLib
             uint8_t         SurfaceRequires64KBTileOptimization(
                                 GMM_TEXTURE_INFO *pTexInfo);
 
+            uint32_t GetWastageTolerentFactorForTile64Surf(GMM_TEXTURE_INFO *pTexInfo);
+            uint8_t DenyComprsnIfSlicePaddingWasteful(GMM_TEXTURE_INFO *pTexInfo);
+            uint8_t DenyComprsnIfDisPackedMipTailWasteful(GMM_TEXTURE_INFO *pTexInfo);
+            void    DoDenyCompression(GMM_TEXTURE_INFO *pTexInfo);
+            uint8_t DenyComprsnIf64KBGranularWasteful(GMM_TEXTURE_INFO *pTexInfo);
+
             GMM_STATUS      PreProcessTexSpecialCases(
                                 GMM_TEXTURE_INFO* pTexInfo);
 
