@@ -114,7 +114,9 @@ typedef struct _SKU_FEATURE_TABLE
         unsigned int   FtrXe2Compression                : 1;  // Xe2 Stateless Compression
 	unsigned int   FtrXe2PlusTiling                 : 1;  // Tile64 MSAA Layout
         unsigned int   FtrL4Cache                       : 1;  // L4 cache support
-        unsigned int   FtrPml5Support                   : 1;  // xe2 page tables		
+        unsigned int   FtrPml5Support                   : 1;  // xe2 page tables
+	unsigned int   Ftr3DSamplerRemoved              : 1;
+	unsigned int   FtrEfficient64BitAddressing      : 1;  //  Efficient 64bit addressing (Xe3P) feature.	
 		
     };
 
@@ -576,6 +578,12 @@ typedef struct _WA_TABLE
         WA_BUG_TYPE_UNKNOWN,
         WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_UNKNOWN)
 
+        WA_DECLARE(
+        Wa_22015614752,
+        "[DG2] - Handle tile4 when Compressed surface not aligned to 64Kb",
+        WA_BUG_TYPE_CORRUPTION,
+        WA_BUG_PERF_IMPACT_UNKNOWN, WA_COMPONENT_GMM)
+
 } WA_TABLE, *PWA_TABLE;
 
 //********************************** SKU/WA Macros *************************************
